/**
 * JASMINe
 * Copyright (C) 2009 Bull S.A.S.
 * Contact: jasmine@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: AckButtonRenderer.as 4798 2009-08-07 12:30:47Z alitokmen $
 * --------------------------------------------------------------------------
 */
package org.ow2.jasmine.monitoring.eos.notification.view.components
{
  import flash.display.DisplayObject;
  import flash.events.*;
  import flash.text.TextField;

  import mx.controls.Button;
  import mx.controls.AdvancedDataGrid;
  import mx.controls.DataGrid;
  import mx.controls.Alert;
  import mx.controls.advancedDataGridClasses.AdvancedDataGridListData;
  import mx.controls.dataGridClasses.DataGridListData;
  import mx.controls.listClasses.BaseListData;
  import mx.controls.listClasses.ListBase;
  import mx.controls.List;
  import mx.managers.*;
  import mx.core.Application;

  import mx.collections.ArrayCollection;


  /**
    * ItemRenderer class that shows a Button in a DataGrid.
    * Clicking the button shows a pop-up window.
    * @author Alina Radu
   */
  public class AckButtonRenderer extends Button
  {
    private var _listData:DataGridListData;

    public var ackPopUp : AckPopUp;

  /**
   * Constructor that sets the button label and the listener.
   */
    public function AckButtonRenderer()
    {
      super();
      this.label = "Ack...";
      this.addEventListener("click",clickButton);
      this.focusEnabled = false;
      this.height = 25;
      this.width = 70;
      this.maxHeight = 25;
      this.maxWidth = 70;
    }

    override public function set data(value:Object):void
    {
      super.data = value;
      //to be reviewed
      invalidateProperties();
    }

    override public function get data():Object
    {
      return super.data;
    }

    override public function get listData():BaseListData
    {
      return _listData;
    }

    override public function set listData(value:BaseListData):void
    {
      _listData = DataGridListData(value);
    }

    override protected function commitProperties():void
    {
      super.commitProperties();

      //to be reviewed
      if (owner is ListBase)
        selected = ListBase(owner).isItemSelected(data);
    }

    /**
     * Eat mouse events, the underlying list will handle them.
     */
    override protected function clickHandler(event:MouseEvent):void
    {
    }

    /**
     * Center the button if we're in a DataGrid.
     * Use the overriden updateDisplayList function
     * of the Button class.
     */
    override protected function updateDisplayList(w:Number, h:Number):void
    {
      super.updateDisplayList(w, h);

      if (listData is DataGridListData)
      {
        var n:int = numChildren;
        for (var i:int = 0; i < n; i++)
        {
          var c:DisplayObject = getChildAt(i);
          if (!(c is TextField))
          {
            c.x = (w - c.width) / 2;
            c.y = 0;
          }
        }
      }
    }


      /**
       * Called when Acknowledge button is being clicked.
       */
      public function clickButton(event:Event):void {
        //show pop-up
        ackPopUp = AckPopUp(PopUpManager.createPopUp(Application.application as DisplayObject, AckPopUp, true));

        //center pop-up
        PopUpManager.centerPopUp(ackPopUp);

        //pass the data provider to the pop-up
        //dirtier method to do that
        //ackPopUp.notifDP = ((event.target as AckButtonRenderer).parent.parent.parent as DataGrid).dataProvider as ArrayCollection;
        ackPopUp.notifDP = (this.listData.owner as DataGrid).dataProvider as ArrayCollection;

        //pass the selected index to the pop-up
        ackPopUp.selectedNotifIndex = this.listData.rowIndex;

      }

  }
}
